Method: Slack::Endpoint::Files#files_startPartialUpload

Defined in:
lib/slack/endpoint/files.rb

#files_startPartialUpload(options = {}) ⇒ Object

This is for starting the upload process of a file. It only requires a filename, and gives back a ticket ID so that later, the upload can be found and updated with all the remaining file info.

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :file (Object)

    File contents via multipart/form-data.

See Also:



158
159
160
# File 'lib/slack/endpoint/files.rb', line 158

def files_startPartialUpload(options={})
  post("files.startPartialUpload", options)
end