Module: Slack::Endpoint::Team

Included in:
Slack::Endpoint
Defined in:
lib/slack/endpoint/team.rb

Instance Method Summary collapse

Instance Method Details

#team_accessLogs(options = {}) ⇒ Object

This method is used to get the access logs for users on a team.

Options Hash (options):

  • :count (Object)

    Number of items to return per page.

  • :page (Object)

    Page number of results to return.

  • :before (Object)

    End of time range of logs to include in results (inclusive).

See Also:



18
19
20
# File 'lib/slack/endpoint/team.rb', line 18

def team_accessLogs(options={})
  post("team.accessLogs", options)
end

#team_billableInfo(options = {}) ⇒ Object

This method lists billable information for each user on the team. Currently this consists solely of whether the user is subject to billing per Slack’s Fair Billing policy.



31
32
33
# File 'lib/slack/endpoint/team.rb', line 31

def team_billableInfo(options={})
  post("team.billableInfo", options)
end

#team_info(options = {}) ⇒ Object

This method provides information about your team.



41
42
43
# File 'lib/slack/endpoint/team.rb', line 41

def team_info(options={})
  post("team.info", options)
end

#team_integrationLogs(options = {}) ⇒ Object

This method lists the integration activity logs for a team, including when integrations are added, modified and removed. This method can only be called by Admins.

Options Hash (options):

  • :service_id (Object)

    Filter logs to this service. Defaults to all logs.

  • :app_id (Object)

    Filter logs to this Slack app. Defaults to all logs.

  • :user (Object)

    Filter logs generated by this user’s actions. Defaults to all logs.

  • :change_type (Object)

    Filter logs with this change type. Defaults to all logs.

  • :count (Object)

    Number of items to return per page.

  • :page (Object)

    Page number of results to return.

See Also:



63
64
65
# File 'lib/slack/endpoint/team.rb', line 63

def team_integrationLogs(options={})
  post("team.integrationLogs", options)
end

#team_profile_get(options = {}) ⇒ Object

This method is used to get the profile field definitions for this team.



75
76
77
# File 'lib/slack/endpoint/team.rb', line 75

def team_profile_get(options={})
  post("team.profile.get", options)
end