Module: Slack::Endpoint::Users
- Included in:
- Slack::Endpoint
- Defined in:
- lib/slack/endpoint/users.rb
Instance Method Summary collapse
-
#users_deletePhoto(options = {}) ⇒ Object
This method allows the user to delete their profile image.
-
#users_getPresence(options = {}) ⇒ Object
This method lets you find out information about a user’s presence.
-
#users_identity(options = {}) ⇒ Object
After your Slack app is awarded an identity token through Sign in with Slack, use this method to retrieve a user’s identity.
-
#users_info(options = {}) ⇒ Object
This method returns information about a team member.
-
#users_list(options = {}) ⇒ Object
This method returns a list of all users in the team.
-
#users_profile_get(options = {}) ⇒ Object
Use this method to retrieve a user’s profile information.
-
#users_profile_set(options = {}) ⇒ Object
Use this method to set a user’s profile information, including name, email, current status, and other attributes.
-
#users_setActive(options = {}) ⇒ Object
This method lets the slack messaging server know that the authenticated user is currently active.
-
#users_setPhoto(options = {}) ⇒ Object
This method allows the user to set their profile image.
-
#users_setPresence(options = {}) ⇒ Object
This method lets you set the calling user’s manual presence.
Instance Method Details
#users_deletePhoto(options = {}) ⇒ Object
This method allows the user to delete their profile image. It will clear whatever image is currently set.
12 13 14 |
# File 'lib/slack/endpoint/users.rb', line 12 def users_deletePhoto(={}) post("users.deletePhoto", ) end |
#users_getPresence(options = {}) ⇒ Object
This method lets you find out information about a user’s presence. Consult the presence documentation for more details.
25 26 27 28 |
# File 'lib/slack/endpoint/users.rb', line 25 def users_getPresence(={}) throw ArgumentError.new("Required arguments :user missing") if [:user].nil? post("users.getPresence", ) end |
#users_identity(options = {}) ⇒ Object
After your Slack app is awarded an identity token through Sign in with Slack, use this method to retrieve a user’s identity.
36 37 38 |
# File 'lib/slack/endpoint/users.rb', line 36 def users_identity(={}) post("users.identity", ) end |
#users_info(options = {}) ⇒ Object
This method returns information about a team member.
48 49 50 51 |
# File 'lib/slack/endpoint/users.rb', line 48 def users_info(={}) throw ArgumentError.new("Required arguments :user missing") if [:user].nil? post("users.info", ) end |
#users_list(options = {}) ⇒ Object
This method returns a list of all users in the team. This includes deleted/deactivated users.
61 62 63 |
# File 'lib/slack/endpoint/users.rb', line 61 def users_list(={}) post("users.list", ) end |
#users_profile_get(options = {}) ⇒ Object
Use this method to retrieve a user’s profile information.
75 76 77 |
# File 'lib/slack/endpoint/users.rb', line 75 def users_profile_get(={}) post("users.profile.get", ) end |
#users_profile_set(options = {}) ⇒ Object
Use this method to set a user’s profile information, including name, email, current status, and other attributes.
93 94 95 |
# File 'lib/slack/endpoint/users.rb', line 93 def users_profile_set(={}) post("users.profile.set", ) end |
#users_setActive(options = {}) ⇒ Object
This method lets the slack messaging server know that the authenticated user is currently active. Consult the presence documentation for more details.
105 106 107 |
# File 'lib/slack/endpoint/users.rb', line 105 def users_setActive(={}) post("users.setActive", ) end |
#users_setPhoto(options = {}) ⇒ Object
This method allows the user to set their profile image. The caller can pass image data via image.
123 124 125 126 |
# File 'lib/slack/endpoint/users.rb', line 123 def users_setPhoto(={}) throw ArgumentError.new("Required arguments :image missing") if [:image].nil? post("users.setPhoto", ) end |
#users_setPresence(options = {}) ⇒ Object
This method lets you set the calling user’s manual presence. Consult the presence documentation for more details.
137 138 139 140 |
# File 'lib/slack/endpoint/users.rb', line 137 def users_setPresence(={}) throw ArgumentError.new("Required arguments :presence missing") if [:presence].nil? post("users.setPresence", ) end |